****************************************
Tools to convert alignment uncertainties
****************************************

This module contains tools to convert alignment uncertainties from one form
into another. Related functionality is also found in `marxs.design.tolerancing`.

Reference / API
===============
.. automodapi:: marxs.design.uncertainties
